<img src="https://github.com/mindsdb/otto/assets/5898506/c1205022-7f73-41cc-82ea-8075801bdbd4" alt="description" style="width: 20%;" />


# Otto: The minimalistic Agent Framework


Welcome to Otto, the most minimalistic library for building intelligent AI Agents straight from Python Objects adept at handling agent multitenancy and secure authentication.

## Agent Multitenancy


Multitenancy allows for running multiple agent instances concurrently, each serving a unique tenant. Otto ensures data isolation and security across tenants.

## Secure Authentication

Otto streamlines agent authentication for third-party services, along with granular access control to services and data, ensuring tailored user access and data integrity.


